@@ -601,8 +601,7 @@ BOOL xyzsh(sObject* block, int* rcode);
 sObject* fd_new_from_stack();
 void fd_delete_stack(sObject* self);
 #define FD_NEW_STACK(kind, fd) fd_new_from_stack(kind, fd)
-BOOL fd_write(sObject* self, char* str);
-BOOL fd_write3(sObject* self, char* str, int size);
+BOOL fd_write(sObject* self, char* str, int size);
 
 sObject* job_new_from_gc(char* name, pid_t pgroup, struct termios tty);
 #define JOB_NEW_GC(o, o2, o3) job_new_from_gc(o, o2, o3)
@@ -665,7 +664,7 @@ extern sObject* gCurrentObject;
 extern sObject* gObject;      // Object class object
 extern sObject* gStackFrames;
 
-BOOL bufsiz_write(int fd, char* buf);
+BOOL bufsiz_write(int fd, char* buf, int buf_len);
 
 BOOL load_file(char* fname, sObject* nextin, sObject* nextout, sRunInfo* runinfo, char** argv, int argc);
 void xyzsh_load_file(char* fname, char** argv, int argc);
@@ -717,6 +716,7 @@ char* sCommand_option_with_argument_item(sCommand* self, char* key);
 BOOL sCommand_put_option(sCommand* self, MANAGED char* key);
 BOOL sCommand_put_option_with_argument(sCommand* self, MANAGED char* key, MANAGED char* argument);
 BOOL sCommand_expand_env(sCommand* command, sObject* object, sObject* nextin, sObject* nextout, sRunInfo* runinfo);
+BOOL sCommand_expand_env_redirect(sCommand* command, sObject* nextin, sObject* nextout, sRunInfo* runinfo);
 void sCommand_sweep_runtime_info(sCommand* command);
 
 extern sObject* gMemChecker;
